#include <cstdio>
#include <string>
#include <set>
using namespace std;

#define MOD 1000000007

struct Number {
  long long value;
  Number() : value(0) {}
  explicit Number(long long v) : value((v < 0 ? v+MOD : v) % MOD) {}
  Number operator+(const Number& other) const { return Number(value + other.value); }
  Number operator-(const Number& other) const { return Number(value - other.value); }
  Number operator*(const Number& other) const { return Number(value * other.value); }
  Number& operator+=(const Number& other) { *this = *this + other; return *this; }
  Number& operator-=(const Number& other) { *this = *this - other; return *this; }
  Number& operator*=(const Number& other) { *this = *this * other; return *this; }
};

struct Parser {
  const string& S;
  int pos = 0;
  bool ok = true;
  explicit Parser(const string& S) : S(S) {}

  char peek() {
    return pos >= (int)S.size() ? '$' : S[pos];
  }

  Number readval() {
    if (peek() == '(') {
      pos++;
      Number res = readadd(')');
      pos++;
      return res;
    }
    if (peek() >= '0' && peek() <= '9') {
      Number val(0);
      while (peek() >= '0' && peek() <= '9') {
        val *= Number(10);
        val += Number(peek() - '0');
        pos++;
      }
      return val;
    }
    ok = false;
    return Number();
  }

  Number readmul() {
    Number val = readval();
    while (peek() == '*') {
      pos++;
      val *= readval();
    }
    return val;
  }

  Number readadd(char end) {
    Number val = readmul();
    while (true) {
      if (peek() == end) return val;
      if (peek() == '+') {
        pos++;
        val += readmul();
        continue;
      }
      if (peek() == '-') {
        pos++;
        val -= readmul();
        continue;
      }
      ok = false;
      return Number();
    }
  }
};

char buf[20000000];

int main() {
  int T;
  scanf("%d", &T);
  while (T--) {
    scanf(" %s", buf);
    string input = buf;

    string chars = "0123456789()+-*";

    set<long long> values;

    for (char& c : input) {
      char orig = c;
      for (char replacement : chars) {
        if (orig == replacement) continue;
        c = replacement;
        Parser p(input);
        Number val = p.readadd('$');
  //      if (orig == '+' || orig == '-' || orig == '*' || (replacement >= '0' && replacement <= '9') || replacement == '*')
        if (p.ok) {
          //fprintf(stderr, "%s -> %lld\n", input.c_str(), val.value);
          values.insert(val.value);
        }
      }
      c = orig;
    }

    printf("%d\n", (int)values.size());
    fflush(stdout);
  }
}
